.. _index:

#####
tmuxp
#####

.. image:: _static/tmuxp-demo.gif
    :width: 100%

.. include:: ../README.rst
    :start-line: 9
    :end-before: Project details

Explore:

.. toctree::
    :maxdepth: 2

    about
    quickstart
    quickstart_python
    examples
    cli
    internals
    developing
    api
    history
    roadmap
    about_tmux
    glossary
